pub struct Quoter { /* private fields */ }Expand description
Partial percent-decoding.
Performs percent-decoding on a slice but can selectively skip decoding certain sequences.
Examples
// + is set as a protected character and will not be decoded...
let q = Quoter::new(&[], b"+");
// ...but the other encoded characters (like the hyphen below) will.
assert_eq!(q.requote(b"/a%2Db%2Bc").unwrap(), b"/a-b%2Bc");Implementations